"""
Author: Michel Peltriaux
Organization: Struktur- und Genehmigungsdirektion Nord, Rhineland-Palatinate, Germany
Contact: michel.peltriaux@sgdnord.rlp.de
Created on: 21.01.22

"""
import json

from django.db.models import QuerySet
from django.http import HttpRequest, JsonResponse

from api.views.v1.general import AbstractModelAPIViewV1
from intervention.models import Intervention


class APIInterventionViewV1(AbstractModelAPIViewV1):
    model = Intervention

    def get(self, request: HttpRequest, id):
        self.lookup["id"] = id
        self.lookup["users__in"] = [self.user]

        data = self.fetch_and_serialize()
        return JsonResponse(data)

    def compensations_to_json(self, qs: QuerySet):
        return list(
            qs.values(
                "id", "identifier", "title"
            )
        )

    def model_to_json(self, entry: Intervention):
        modified_on = entry.modified or entry.created
        modified_on = modified_on.timestamp
        entry_json = {
            "identifier": entry.identifier,
            "title": entry.title,
            "responsible": self.responsible_to_json(entry.responsible),
            "legal": self.legal_to_json(entry.legal),
            "compensations": self.compensations_to_json(entry.compensations.all()),
            "payments": self.payments_to_json(entry.payments.all()),
            "deductions": self.deductions_to_json(entry.deductions.all()),
            "modified_on": modified_on,
            "created_on": entry.created.timestamp,
        }
        geom = entry.geometry.geom.geojson
        geo_json = json.loads(geom)
        geo_json["properties"] = entry_json
        return geo_json